@@ -1,10 +1,11 @@
 from __future__ import absolute_import, division, print_function
 
 import os
-import sys
 import imp
-import logging
+import sys
 from collections import namedtuple
+from glue.logger import logger
+
 """
 Objects used to configure Glue at runtime.
 """
@@ -71,7 +72,7 @@ class Registry(object):
         self._lazy_members.append(value)
 
     def _load_lazy_members(self):
-        from .plugins import load_plugin
+        from glue.plugins import load_plugin
         while self._lazy_members:
             plugin = self._lazy_members.pop()
             load_plugin(plugin)
@@ -337,8 +338,8 @@ class DataFactoryRegistry(Registry):
 
 
 class QtClientRegistry(Registry):
-
-    """Stores QT widgets to visualize data.
+    """
+    Stores QT widgets to visualize data.
 
     The members property is a list of Qt widget classes
 
@@ -349,16 +350,6 @@ class QtClientRegistry(Registry):
             ...
     """
 
-    def default_members(self):
-        try:
-            from .qt.widgets import default_widgets
-            from .qt.custom_viewer import CUSTOM_WIDGETS
-            return default_widgets + CUSTOM_WIDGETS
-        except ImportError as e:
-            logging.getLogger(__name__).warning(
-                "could not import glue.qt in ConfigObject")
-            return []
-
 
 class QtToolRegistry(DictRegistry):
 
@@ -368,8 +359,7 @@ class QtToolRegistry(DictRegistry):
             try:
                 defaults[viewer] = viewer._get_default_tools()
             except AttributeError:
-                logging.getLogger(__name__).warning(
-                    "could not get default tools for {0}".format(viewer.__name__))
+                logger.info("could not get default tools for {0}".format(viewer.__name__))
                 defaults[viewer] = []
 
         return defaults
@@ -406,7 +396,7 @@ class LinkFunctionRegistry(Registry):
     item = namedtuple('LinkFunction', 'function info output_labels')
 
     def default_members(self):
-        from .core import link_helpers
+        from glue.core import link_helpers
         return list(self.item(l, "", l.output_args)
                     for l in link_helpers.__LINK_FUNCTIONS__)
 
@@ -457,7 +447,7 @@ class LinkHelperRegistry(Registry):
     item = namedtuple('LinkHelper', 'helper info input_labels')
 
     def default_members(self):
-        from .core.link_helpers import __LINK_HELPERS__ as helpers
+        from glue.core.link_helpers import __LINK_HELPERS__ as helpers
         return list(self.item(l, l.info_text, l.input_args)
                     for l in helpers)
 
@@ -478,7 +468,7 @@ class ProfileFitterRegistry(Registry):
         self.members.append(cls)
 
     def default_members(self):
-        from .core.fitters import __FITTERS__
+        from glue.core.fitters import __FITTERS__
         return list(__FITTERS__)
 
 
@@ -553,7 +543,7 @@ def _default_search_order():
        * Glue's own default config
     """
 
-    from . import config
+    from glue import config
 
     search_order = [os.path.join(os.getcwd(), 'config.py')]
     if 'GLUERC' in os.environ:
@@ -564,7 +554,7 @@ def _default_search_order():
 
 ###### Now define global settings ######
 
-GRAY = '#373737'
+GRAY = '#7F7F7F'
 BLUE = "#1F78B4"
 GREEN = "#33A02C"
 RED = "#E31A1C"
