@@ -1,15 +1,15 @@
+from __future__ import absolute_import, division, print_function
+
 import logging
 
 import numpy as np
+
 try:
     from plotly import plotly
 except ImportError:
     plotly = None
 
-from ..qt.widgets import ScatterWidget, HistogramWidget
-from ..core.data import CategoricalComponent
-from ..core.layout import Rectangle, snap_to_grid
-
+from glue.core.layout import Rectangle, snap_to_grid
 
 SYM = {'o': 'circle', 's': 'square', '+': 'cross', '^': 'triangle-up',
        '*': 'cross'}
@@ -24,7 +24,7 @@ def _data(layer, component):
     """
     result = layer[component]
     comp = layer.data.get_component(component)
-    if isinstance(comp, CategoricalComponent):
+    if comp.categorical:
         result = comp.categories[result.astype(np.int)]
     return result
 
@@ -155,8 +155,8 @@ def export_scatter(viewer):
         if not layer.visible:
             continue
         l = layer.layer
-        xcat |= isinstance(l.data.get_component(xatt), CategoricalComponent)
-        ycat |= isinstance(l.data.get_component(yatt), CategoricalComponent)
+        xcat |= l.data.get_component(xatt).categorical
+        ycat |= l.data.get_component(yatt).categorical
 
         marker = dict(symbol=SYM.get(l.style.marker, 'circle'),
                       color=_color(l.style),
@@ -215,9 +215,6 @@ def build_plotly_call(app):
     args = []
     layout = {'showlegend': True, 'barmode': 'overlay',
               'title': 'Autogenerated by Glue'}
-    dispatch = {ScatterWidget: export_scatter,
-                HistogramWidget: export_histogram
-                }
 
     ct = 1
     for tab in app.viewers:
@@ -225,8 +222,8 @@ def build_plotly_call(app):
             if hasattr(viewer, '__plotly__'):
                 p, xaxis, yaxis = viewer.__plotly__()
             else:
-                assert type(viewer) in dispatch
-                p, xaxis, yaxis = dispatch[type(viewer)](viewer)
+                assert type(viewer) in DISPATCH
+                p, xaxis, yaxis = DISPATCH[type(viewer)](viewer)
 
             xaxis['zeroline'] = False
             yaxis['zeroline'] = False
@@ -304,8 +301,21 @@ def save_plotly(application, label):
     plotly.sign_in(user, apikey)
     plotly.plot(*args, **kwargs)
 
+
 def setup():
-    from ..config import exporters, settings
+    from glue.config import exporters, settings
     exporters.add('Plotly', save_plotly, can_save_plotly, outmode='label')
     settings.add('PLOTLY_USER', 'Glue')
     settings.add('PLOTLY_APIKEY', 't24aweai14')
+
+
+DISPATCH = {}
+
+try:
+    from glue.viewers.scatter.qt import ScatterWidget
+    from glue.viewers.histogram.qt import HistogramWidget
+except ImportError:
+    pass
+else:
+    DISPATCH[ScatterWidget] = export_scatter
+    DISPATCH[HistogramWidget] = export_histogram
